@@ -427,6 +427,8 @@ class CaenN6725(object):
 
         self.digitizer.calibrate()
         self.digitizer.start_acquisition()
+        if self.has_dpp_pha_firmware:
+            self.digitizer.clear_energy_histogram()
         delta_t = 0
         last = time.monotonic()
         while delta_t <= seconds:
